@@ -179,7 +179,10 @@ impl Operation {
                 false
             } else if attr.path.is_ident("doc") {
                 if let Ok(d) = syn::parse2::<DocString>(attr.tokens.clone()) {
-                    doc_val += &d.content.value();
+                    let val = d.content.value();
+                    let v = val.strip_prefix(' ').unwrap_or(&val).trim_end();
+                    doc_val += v;
+                    doc_val += "\n";
                 };
                 true
             } else if attr.path.is_ident("get")
